Bifrost: File List

Bifrost

File List
Here is a list of all documented files with brief descriptions:
[detail level 12]

▼ src |
ColoredCDBG.hpp | Interface for the Colored and Compacted de Bruijn graph API
ColorSet.hpp | Interface for UnitigColors, the unitig container of k-mer color sets used in ColoredCDBG
CompactedDBG.hpp | Interface for the Compacted de Bruijn graph API
DataAccessor.hpp | Interface for the class DataAccessor
Kmer.hpp | Interface for the class Kmer:
NeighborIterator.hpp | The neighborIterator, BackwardCDBG and ForwardCDBG type interfaces
Unitig.hpp | The Unitig interface
UnitigIterator.hpp | The unitigIterator type interface
UnitigMap.hpp | UnitigMap type interface